==============================================================
``psyclone.domain.gocean.transformations.gocean_opencl_trans``
==============================================================

.. automodule:: psyclone.domain.gocean.transformations.gocean_opencl_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.gocean.transformations.gocean_opencl_trans


Classes
=======

- :py:class:`GOOpenCLTrans`:
  Switches on/off the generation of an OpenCL PSy layer for a given


.. autoclass:: GOOpenCLTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: GOOpenCLTrans
      :parts: 1
